@@ -1,7 +1,7 @@
 test_that("simFossilRecord doesn't return extinct taxa in extant-only simulations", {
 
 testthat::skip_on_cran()
-testthat::skip_on_travis()
+testthat::skip_on_ci()
 
 library(paleotree)
 
